import type { Registration } from '@salesforce/lds-default-luvio';
import type { DraftAwareCreateContentDocumentAndVersionAdapter } from './wire/createContentDocumentAndVersion/configurationTypes';
import type { DraftAwareCreateContentVersionAdapter } from './wire/createContentVersion/configurationTypes';
import type { DraftAwareCreateRecordAdapter } from './wire/createRecord/configurationTypes';
import type { DraftAwareUpdateRecordAdapter } from './wire/updateRecord/configurationTypes';
import type { DraftAwareDeleteRecordAdapter } from './wire/deleteRecord/configurationTypes';
import type { DraftAwarePerformQuickActionAdapter } from './wire/performQuickAction/configurationTypes';
import type { DraftAwarePerformUpdateRecordQuickActionAdapter } from './wire/performUpdateRecordQuickAction/configurationTypes';
import type { DraftAwareGraphQLAdapter } from './wire/graphql/configurationTypes';
import type { EnvironmentAwareGraphQLBatchAdapter } from './wire/graphqlBatch/configurationTypes';
import type { WireAdapterConstructor } from '@lwc/engine-core';
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for one store enabled REST adapters only.
 */
export declare const configurationForOneStoreEnabledAdapters: {
    setGetObjectInfoAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfoAdapter: () => WireAdapterConstructor | undefined;
    setGetObjectInfosAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfosAdapter: () => WireAdapterConstructor | undefined;
};
/**
 * Helper function to return the one store adapter if it's defined, otherwise return the luvio adapter.
 * @param luvioAdapter - The luvio bound adapter.
 * @param oneStoreAdapter - The one store bound adapter.
 * @returns Luvio or one store wire adapter constructor.
 */
export declare function getLuvioOrOneStoreAdapter(luvioAdapter: WireAdapterConstructor, oneStoreAdapter: WireAdapterConstructor | undefined): WireAdapterConstructor;
import type { ResourceIngest } from '@luvio/engine';
export declare const configurationForEnvironmentFactoryOverrides: {
    getKeywordSearchResultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getKeywordSearchResults").GetKeywordSearchResultsConfig, import("./generated/types/KeywordSearchResultsSummaryRepresentation").KeywordSearchResultsSummaryRepresentation> | undefined;
    setGetKeywordSearchResultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getKeywordSearchResults").GetKeywordSearchResultsConfig, import("./generated/types/KeywordSearchResultsSummaryRepresentation").KeywordSearchResultsSummaryRepresentation>) => void;
    getListRecordsByNameAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./main").GetListRecordsByNameConfig, import("./generated/types/ListRecordCollectionRepresentation").ListRecordCollectionRepresentation> | undefined;
    setGetListRecordsByNameAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./main").GetListRecordsByNameConfig, import("./generated/types/ListRecordCollectionRepresentation").ListRecordCollectionRepresentation>) => void;
    getListUiAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getListViewSummaryCollection").GetListViewSummaryCollectionConfig | import("./generated/adapters/getListUiByApiName").GetListUiByApiNameConfig | import("./generated/adapters/getListUiByListViewId").GetListUiByListViewIdConfig | import("./generated/adapters/getMruListUi").GetMruListUiConfig, import("./generated/types/ListUiRepresentation").ListUiRepresentation | import("./generated/types/ListViewSummaryCollectionRepresentation").ListViewSummaryCollectionRepresentation> | undefined;
    setGetListUiAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getListViewSummaryCollection").GetListViewSummaryCollectionConfig | import("./generated/adapters/getListUiByApiName").GetListUiByApiNameConfig | import("./generated/adapters/getListUiByListViewId").GetListUiByListViewIdConfig | import("./generated/adapters/getMruListUi").GetMruListUiConfig, import("./generated/types/ListUiRepresentation").ListUiRepresentation | import("./generated/types/ListViewSummaryCollectionRepresentation").ListViewSummaryCollectionRepresentation>) => void;
    getLookupRecordsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getLookupRecords").GetLookupRecordsConfig, import("./generated/types/LookupValuesRepresentation").LookupValuesRepresentation> | undefined;
    setGetLookupRecordsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getLookupRecords").GetLookupRecordsConfig, import("./generated/types/LookupValuesRepresentation").LookupValuesRepresentation>) => void;
    getQuickActionDefaultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getQuickActionDefaults").GetQuickActionDefaultsConfig, import("./generated/types/QuickActionDefaultsRepresentation").QuickActionDefaultsRepresentation> | undefined;
    setGetQuickActionDefaultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getQuickActionDefaults").GetQuickActionDefaultsConfig, import("./generated/types/QuickActionDefaultsRepresentation").QuickActionDefaultsRepresentation>) => void;
    getRecordCreateDefaultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordCreateDefaults").GetRecordCreateDefaultsConfig, import("./generated/types/RecordDefaultsRepresentation").RecordDefaultsRepresentation> | undefined;
    setGetRecordCreateDefaultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordCreateDefaults").GetRecordCreateDefaultsConfig, import("./generated/types/RecordDefaultsRepresentation").RecordDefaultsRepresentation>) => void;
    getRecordTemplateCloneAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateClone").GetRecordTemplateCloneConfig, import("./generated/types/RecordDefaultsTemplateCloneRepresentation").RecordDefaultsTemplateCloneRepresentation> | undefined;
    setGetRecordTemplateCloneAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateClone").GetRecordTemplateCloneConfig, import("./generated/types/RecordDefaultsTemplateCloneRepresentation").RecordDefaultsTemplateCloneRepresentation>) => void;
    getRecordTemplateCreateAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateCreate").GetRecordTemplateCreateConfig, import("./generated/types/RecordDefaultsTemplateCreateRepresentation").RecordDefaultsTemplateCreateRepresentation> | undefined;
    setGetRecordTemplateCreateAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateCreate").GetRecordTemplateCreateConfig, import("./generated/types/RecordDefaultsTemplateCreateRepresentation").RecordDefaultsTemplateCreateRepresentation>) => void;
    getRecordUiAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordUi").GetRecordUiConfig, import("./generated/types/RecordUiRepresentation").RecordUiRepresentation> | undefined;
    setGetRecordUiAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordUi").GetRecordUiConfig, import("./generated/types/RecordUiRepresentation").RecordUiRepresentation>) => void;
    getRecordAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./main").GetRecordConfig, import("./main").RecordRepresentation> | undefined;
    setGetRecordAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./main").GetRecordConfig, import("./main").RecordRepresentation>) => void;
    getRecordsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./main").GetRecordsConfig, import("./main").BatchRepresentation> | undefined;
    setGetRecordsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./main").GetRecordsConfig, import("./main").BatchRepresentation>) => void;
    getRelatedListRecordsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecords").GetRelatedListRecordsConfig, import("./main").RelatedListRecordCollectionRepresentation> | undefined;
    setGetRelatedListRecordsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecords").GetRelatedListRecordsConfig, import("./main").RelatedListRecordCollectionRepresentation>) => void;
    getRelatedListRecordsBatchAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecordsBatch").GetRelatedListRecordsBatchConfig, import("./main").RelatedListRecordCollectionBatchRepresentation> | undefined;
    setGetRelatedListRecordsBatchAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecordsBatch").GetRelatedListRecordsBatchConfig, import("./main").RelatedListRecordCollectionBatchRepresentation>) => void;
    getSearchResultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getSearchResults").GetSearchResultsConfig, import("./generated/types/SearchResultsSummaryRepresentation").SearchResultsSummaryRepresentation> | undefined;
    setGetSearchResultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getSearchResults").GetSearchResultsConfig, import("./generated/types/SearchResultsSummaryRepresentation").SearchResultsSummaryRepresentation>) => void;
};
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for REST adapters only.
 */
export declare const configurationForRestAdapters: {
    getKeywordSearchResultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getKeywordSearchResults").GetKeywordSearchResultsConfig, import("./generated/types/KeywordSearchResultsSummaryRepresentation").KeywordSearchResultsSummaryRepresentation> | undefined;
    setGetKeywordSearchResultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getKeywordSearchResults").GetKeywordSearchResultsConfig, import("./generated/types/KeywordSearchResultsSummaryRepresentation").KeywordSearchResultsSummaryRepresentation>) => void;
    getListRecordsByNameAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./main").GetListRecordsByNameConfig, import("./generated/types/ListRecordCollectionRepresentation").ListRecordCollectionRepresentation> | undefined;
    setGetListRecordsByNameAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./main").GetListRecordsByNameConfig, import("./generated/types/ListRecordCollectionRepresentation").ListRecordCollectionRepresentation>) => void;
    getListUiAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getListViewSummaryCollection").GetListViewSummaryCollectionConfig | import("./generated/adapters/getListUiByApiName").GetListUiByApiNameConfig | import("./generated/adapters/getListUiByListViewId").GetListUiByListViewIdConfig | import("./generated/adapters/getMruListUi").GetMruListUiConfig, import("./generated/types/ListUiRepresentation").ListUiRepresentation | import("./generated/types/ListViewSummaryCollectionRepresentation").ListViewSummaryCollectionRepresentation> | undefined;
    setGetListUiAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getListViewSummaryCollection").GetListViewSummaryCollectionConfig | import("./generated/adapters/getListUiByApiName").GetListUiByApiNameConfig | import("./generated/adapters/getListUiByListViewId").GetListUiByListViewIdConfig | import("./generated/adapters/getMruListUi").GetMruListUiConfig, import("./generated/types/ListUiRepresentation").ListUiRepresentation | import("./generated/types/ListViewSummaryCollectionRepresentation").ListViewSummaryCollectionRepresentation>) => void;
    getLookupRecordsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getLookupRecords").GetLookupRecordsConfig, import("./generated/types/LookupValuesRepresentation").LookupValuesRepresentation> | undefined;
    setGetLookupRecordsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getLookupRecords").GetLookupRecordsConfig, import("./generated/types/LookupValuesRepresentation").LookupValuesRepresentation>) => void;
    getQuickActionDefaultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getQuickActionDefaults").GetQuickActionDefaultsConfig, import("./generated/types/QuickActionDefaultsRepresentation").QuickActionDefaultsRepresentation> | undefined;
    setGetQuickActionDefaultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getQuickActionDefaults").GetQuickActionDefaultsConfig, import("./generated/types/QuickActionDefaultsRepresentation").QuickActionDefaultsRepresentation>) => void;
    getRecordCreateDefaultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordCreateDefaults").GetRecordCreateDefaultsConfig, import("./generated/types/RecordDefaultsRepresentation").RecordDefaultsRepresentation> | undefined;
    setGetRecordCreateDefaultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordCreateDefaults").GetRecordCreateDefaultsConfig, import("./generated/types/RecordDefaultsRepresentation").RecordDefaultsRepresentation>) => void;
    getRecordTemplateCloneAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateClone").GetRecordTemplateCloneConfig, import("./generated/types/RecordDefaultsTemplateCloneRepresentation").RecordDefaultsTemplateCloneRepresentation> | undefined;
    setGetRecordTemplateCloneAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateClone").GetRecordTemplateCloneConfig, import("./generated/types/RecordDefaultsTemplateCloneRepresentation").RecordDefaultsTemplateCloneRepresentation>) => void;
    getRecordTemplateCreateAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateCreate").GetRecordTemplateCreateConfig, import("./generated/types/RecordDefaultsTemplateCreateRepresentation").RecordDefaultsTemplateCreateRepresentation> | undefined;
    setGetRecordTemplateCreateAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordTemplateCreate").GetRecordTemplateCreateConfig, import("./generated/types/RecordDefaultsTemplateCreateRepresentation").RecordDefaultsTemplateCreateRepresentation>) => void;
    getRecordUiAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordUi").GetRecordUiConfig, import("./generated/types/RecordUiRepresentation").RecordUiRepresentation> | undefined;
    setGetRecordUiAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRecordUi").GetRecordUiConfig, import("./generated/types/RecordUiRepresentation").RecordUiRepresentation>) => void;
    getRecordAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./main").GetRecordConfig, import("./main").RecordRepresentation> | undefined;
    setGetRecordAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./main").GetRecordConfig, import("./main").RecordRepresentation>) => void;
    getRecordsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./main").GetRecordsConfig, import("./main").BatchRepresentation> | undefined;
    setGetRecordsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./main").GetRecordsConfig, import("./main").BatchRepresentation>) => void;
    getRelatedListRecordsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecords").GetRelatedListRecordsConfig, import("./main").RelatedListRecordCollectionRepresentation> | undefined;
    setGetRelatedListRecordsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecords").GetRelatedListRecordsConfig, import("./main").RelatedListRecordCollectionRepresentation>) => void;
    getRelatedListRecordsBatchAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecordsBatch").GetRelatedListRecordsBatchConfig, import("./main").RelatedListRecordCollectionBatchRepresentation> | undefined;
    setGetRelatedListRecordsBatchAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getRelatedListRecordsBatch").GetRelatedListRecordsBatchConfig, import("./main").RelatedListRecordCollectionBatchRepresentation>) => void;
    getSearchResultsAdapterFactory: () => import("@luvio/engine").AdapterFactory<import("./generated/adapters/getSearchResults").GetSearchResultsConfig, import("./generated/types/SearchResultsSummaryRepresentation").SearchResultsSummaryRepresentation> | undefined;
    setGetSearchResultsAdapterFactory: (value: import("@luvio/engine").AdapterFactory<import("./generated/adapters/getSearchResults").GetSearchResultsConfig, import("./generated/types/SearchResultsSummaryRepresentation").SearchResultsSummaryRepresentation>) => void;
    setGetObjectInfoAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfoAdapter: () => WireAdapterConstructor | undefined;
    setGetObjectInfosAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfosAdapter: () => WireAdapterConstructor | undefined;
    setTrackedFieldDepthOnCacheMiss: (trackedFieldDepthOnCacheMissParam: number) => void;
    getTrackedFieldDepthOnCacheMiss: () => number;
    setTrackedFieldDepthOnCacheMergeConflict: (trackedFieldDepthOnCacheMergeConflictParam: number) => void;
    getTrackedFieldDepthOnCacheMergeConflict: () => number;
    setTrackedFieldDepthOnNotifyChange: (trackedFieldDepthOnNotifyChangeParam: number) => void;
    getTrackedFieldDepthOnNotifyChange: () => number;
    setTrackedFieldLeafNodeIdAndNameOnly: (trackedFieldLeafNodeIdAndNameOnlyParam: boolean) => void;
    getTrackedFieldLeafNodeIdAndNameOnly: () => boolean;
    setRelatedListsPredictionsEnabled: (f: boolean) => void;
    areRelatedListsPredictionsEnabled: () => boolean;
    setRelatedListsPlusPredictionsEnabled: (f: boolean) => void;
    areRelatedListsPlusPredictionsEnabled: () => boolean;
    setRecordRepresentationIngestionOverride: (ingest: ResourceIngest) => void;
    getRecordRepresentationIngestionOverride: () => ResourceIngest | undefined;
    getDraftAwareCreateRecordAdapter: () => DraftAwareCreateRecordAdapter | undefined;
    setDraftAwareCreateRecordAdapter: (value: DraftAwareCreateRecordAdapter) => void;
    getDraftAwareUpdateRecordAdapter: () => DraftAwareUpdateRecordAdapter | undefined;
    setDraftAwareUpdateRecordAdapter: (value: DraftAwareUpdateRecordAdapter) => void;
    getDraftAwareDeleteRecordAdapter: () => DraftAwareDeleteRecordAdapter | undefined;
    setDraftAwareDeleteRecordAdapter: (value: DraftAwareDeleteRecordAdapter) => void;
    getDraftAwarePerformQuickActionAdapter: () => DraftAwarePerformQuickActionAdapter | undefined;
    setDraftAwarePerformQuickActionAdapter: (value: DraftAwarePerformQuickActionAdapter) => void;
    getDraftAwarePerformUpdateRecordQuickActionAdapter: () => DraftAwarePerformUpdateRecordQuickActionAdapter | undefined;
    setDraftAwarePerformUpdateRecordQuickActionAdapter: (value: DraftAwarePerformUpdateRecordQuickActionAdapter) => void;
    getDraftAwareCreateContentDocumentAndVersionAdapter: () => DraftAwareCreateContentDocumentAndVersionAdapter | undefined;
    setDraftAwareCreateContentDocumentAndVersionAdapter: (value: DraftAwareCreateContentDocumentAndVersionAdapter) => void;
    getDraftAwareCreateContentVersionAdapter: () => DraftAwareCreateContentVersionAdapter | undefined;
    setDraftAwareCreateContentVersionAdapter: (value: DraftAwareCreateContentVersionAdapter) => void;
};
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for GraphQL adapters only.
 */
export declare const configurationForGraphQLAdapters: {
    getDraftAwareGraphQLAdapter: () => DraftAwareGraphQLAdapter | undefined;
    setDraftAwareGraphQLAdapter: (value: DraftAwareGraphQLAdapter) => void;
    getEnvironmentAwareGraphQLBatchAdapter: () => EnvironmentAwareGraphQLBatchAdapter | undefined;
    setEnvironmentAwareGraphQLBatchAdapter: (value: EnvironmentAwareGraphQLBatchAdapter) => void;
};
/**
 * Note: configuration isn't shared across REST and GraphQL adapters
 * It needs to be set explicitly for each adapter module in core
 */
export type ConfigurationForRestAdapters = typeof configurationForRestAdapters;
export type ConfigurationForGraphQLAdapters = typeof configurationForGraphQLAdapters;
export type ConfigurationForOneStoreEnabledAdapters = typeof configurationForOneStoreEnabledAdapters;
/**
 * lds-adapter-uiapi is special.  The non-SFDC bundle combines REST and GQL adapters,
 * yet for SFDC those are separate bundles.  So non-SFDC bundle (./main.ts) registers
 * both REST and GQL configs.  We want each SFDC bundle to register (we don't want one
 * SFDC bundle to assume the other is being loaded and therefore the other one will
 * take care of registration) but we don't want to double register either.
 *
 * So we make this function that memoizes if it's been called before and only
 * actually registers once.
 */
export declare function ensureRegisteredOnce<R extends Registration = Registration>(registration: R): void;
