import type { PaginationMetadata, offsetFromToken, tokenForAtMost } from '../generated/pagination/cursor';
/**
 * Examines a set of paginated data & metadata from an UnfulfilledSnapshot and computes a
 * pageToken and pageSize that will minimize the amount of data requested while still
 * satisfying the original request.
 *
 * @param config.name name of the field within data that contains the items
 * @param conifg.data paginated data/metadata from an UnfulfilledSnapshot
 * @param config.pageSize requested pageSize
 * @param config.pagination pagination data/functions from engine
 * @returns pageToken & pageSize to fill in the missing data
 */
export declare function minimizeRequest(config: {
    name: string;
    data: any | null;
    pageToken: string | undefined;
    pageSize: number;
    pagination: {
        offsetFromToken: typeof offsetFromToken;
        tokenForAtMost: typeof tokenForAtMost;
        paginationMetadata: PaginationMetadata;
    };
}): {
    pageToken: string | undefined;
    pageSize: number;
};
